@@ -2,9 +2,6 @@
 
 package App::pmgrep;
 
-our $DATE = '2021-07-27'; # DATE
-our $VERSION = '0.735'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -13,6 +10,11 @@ use Log::ger;
 use AppBase::Grep;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-08-27'; # DATE
+our $DIST = 'App-PMUtils'; # DIST
+our $VERSION = '0.736'; # VERSION
+
 our %SPEC;
 
 gen_modified_sub(
@@ -144,7 +146,7 @@ App::pmgrep - Print lines from installed Perl module sources matching a pattern
 
 =head1 VERSION
 
-This document describes version 0.735 of App::pmgrep (from Perl distribution App-PMUtils), released on 2021-07-27.
+This document describes version 0.736 of App::pmgrep (from Perl distribution App-PMUtils), released on 2021-08-27.
 
 =head1 FUNCTIONS
 
@@ -248,6 +250,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtil
 
 Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PMUtils>
@@ -256,15 +286,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
